@@ -1,7 +1,18 @@
 import errno
 from urllib.parse import urljoin, urlsplit
 
-from requests.exceptions import InvalidJSONError, RequestException
+from requests.exceptions import RequestException
+
+# InvalidJSONError was added in requests 2.26.0.  RHEL 9 only has requests
+# 2.25.1.  If we can't import it, define it ourselves.
+try:
+    from requests.exceptions import InvalidJSONError
+except ImportError:  # pragma: no cover
+
+    class InvalidJSONError(RequestException):
+        pass
+
+
 from bravado import requests_client
 from bravado.client import SwaggerClient, CallableOperation
 from bravado.exception import HTTPError
@@ -10,6 +21,7 @@ from swagger_spec_validator.common import SwaggerValidationError
 from .gss_http import GssapiAuthenticator
 from .errors import ClientSetupError
 from .response import ResponseWrapper
+from .formats import mask_format
 
 
 class Client:
@@ -34,6 +46,9 @@ class Client:
         self._bravado_config = bravado_config or {}
         self._auth = auth
         # self._bravado_config.setdefault("disable_fallback_results", True)
+        # Register the mask format
+        self._bravado_config.setdefault("formats", []).append(mask_format)
+
         self._api = self._make_bravado_client()
         self._ops = self._make_ops_map()
 
@@ -98,7 +113,7 @@ class Client:
         except KeyError:
             raise AttributeError("No such operation: {!r}".format(name))
 
-    def list_all_entities(self, entity_name, page_size=1000):
+    def list_all_entities(self, entity_name, page_size=1000, **kwargs):
         try:
             operation = self._ops["list_{}".format(entity_name)]
         except KeyError:
@@ -109,6 +124,6 @@ class Client:
         next_page_exists = True
         while next_page_exists:
             page_number += 1
-            response = operation(page_size=page_size, page_number=page_number)
+            response = operation(page_size=page_size, page_number=page_number, **kwargs)
             yield from response.result
             next_page_exists = page_number < response.page["total_pages"]
