@@ -4,6 +4,23 @@ from fasjson_client.client import Client
 from fasjson_client.errors import APIError
 
 
+@pytest.fixture
+def server_with_empty_response(server):
+    server.mock_endpoint(
+        "/users/",
+        [
+            {
+                "json": {
+                    "result": [],
+                    "page": {"page_number": 1, "page_size": 2, "total_pages": 1},
+                }
+            }
+        ],
+        method="GET",
+    )
+    return server
+
+
 def test_api_success(server):
     mocked = {"result": {"dn": "SRV/foo@bar,dc=example.test", "service": "SRV/foo"}}
     server.mock_endpoint("/me/", json=mocked)
@@ -111,3 +128,32 @@ def test_list_all_entities_wrong_name(server):
     client = Client("http://example.com/fasjson")
     with pytest.raises(ValueError):
         list(client.list_all_entities("foobar"))
+
+
+def test_list_entities_headers(server_with_empty_response):
+    server = server_with_empty_response
+    client = Client("http://example.com/fasjson")
+    result = client.list_all_entities(
+        "users",
+        page_size=2,
+        _request_options={
+            "headers": {"X-Test": "foobar", "X-Fields": ["field1", "field2"]}
+        },
+    )
+    assert list(result) == []
+    req = server.reqs.request_history[-1]
+    assert req.headers.get("X-Test") == "foobar"
+    assert req.headers.get("X-Fields") == "field1,field2"
+
+
+def test_list_entities_fields_as_string(server_with_empty_response):
+    server = server_with_empty_response
+    client = Client("http://example.com/fasjson")
+    result = client.list_all_entities(
+        "users",
+        page_size=2,
+        _request_options={"headers": {"X-Fields": "field1"}},
+    )
+    assert list(result) == []
+    req = server.reqs.request_history[-1]
+    assert req.headers.get("X-Fields") == "field1"
